@@ -176,7 +176,7 @@ static gboolean callerid_widget_expose_event (GtkWidget *widget, GdkEventExpose
 	cairo_t *cr;
 	gint width, height, x, y;
 	gint radius = 5;
-	
+
 	cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
 	gdk_cairo_region (cr, event->region);
 	cairo_clip (cr);
@@ -211,12 +211,12 @@ static gboolean callerid_widget_expose_event (GtkWidget *widget, GdkEventExpose
 	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 
 	cairo_fill_preserve (cr);
-	
+
 	gtk_style_lookup_color (gtk_rc_get_style (widget), "ActiveTextColor", &color);
 	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
 	cairo_set_line_width (cr, 1);
 	cairo_stroke (cr);
-	
+
 	cairo_destroy (cr);
 
 	return GTK_WIDGET_CLASS (callerid_widget_parent_class)->expose_event (widget, event);
@@ -337,10 +337,10 @@ static void callerid_widget_on_ready_update (McAccount *account, const GError *e
 	{
 		if (g_str_equal (key, TELEPATHY_PROPERTY))
 			continue;
-		
+
 		g_hash_table_insert (new_params, key, value);
 	}
-	
+
 	g_value_init (&gvalue, G_TYPE_STRING);
 	g_value_set_static_string (&gvalue, self->priv->new_tp_state);
 	g_hash_table_insert (new_params, TELEPATHY_PROPERTY, &gvalue);
@@ -389,7 +389,7 @@ static gboolean callerid_widget_button_release (GtkWidget *widget, GdkEventButto
 	if (event->button == 1 && self->priv->isPressed)
 	{
 		self->priv->isPressed = FALSE;
-	
+
 		callerid_widget_new_callerid_combo (self);
 		gtk_widget_queue_draw (widget);
 
@@ -405,7 +405,7 @@ static gboolean callerid_widget_button_press (GtkWidget *widget, GdkEventButton
 	{
 		self->priv->isPressed = TRUE;
 		gtk_widget_queue_draw (widget);
-		
+
 		return TRUE;
 	}
 
@@ -431,7 +431,7 @@ static void callerid_widget_content_create (CallerIDWidget *self)
 	g_signal_connect (self, "button-press-event", G_CALLBACK (callerid_widget_button_press), self);
 	//g_signal_connect (self, "leave-notify-event", G_CALLBACK (callerid_widget_leave_event), self);
 
-    gtk_widget_show_all (self->priv->homeWidget);
+	gtk_widget_show_all (self->priv->homeWidget);
 }
 
 static gboolean callerid_widget_update_content (CallerIDWidget *self)
@@ -458,7 +458,7 @@ static void callerid_widget_done_constructing (GObject *gobject)
 
 static void callerid_widget_init (CallerIDWidget *self)
 {
-    TpDBusDaemon *daemon = tp_dbus_daemon_dup (NULL);
+	TpDBusDaemon *daemon = tp_dbus_daemon_dup (NULL);
 
 	self->priv = CALLERID_WIDGET_GET_PRIVATE (self);
 	g_return_if_fail (G_LIKELY (self->priv != NULL));
@@ -468,13 +468,13 @@ static void callerid_widget_init (CallerIDWidget *self)
 	self->priv->ring_acc = mc_account_new (daemon, TELEPATHY_RING_PATH);
 	g_object_unref (daemon);
 
-	self->priv->sess_dbus_conn = hd_home_plugin_item_get_dbus_g_connection (&self->parent, DBUS_BUS_SESSION, NULL);
+	self->priv->sess_dbus_conn = hd_home_plugin_item_get_dbus_g_connection (HD_HOME_PLUGIN_ITEM (self), DBUS_BUS_SESSION, NULL);
 	self->priv->ring_proxy = dbus_g_proxy_new_for_name (self->priv->sess_dbus_conn, TELEPATHY_SERVICE, TELEPATHY_RING_PATH, TELEPATHY_INTERACE);
 
 	dbus_g_proxy_add_signal (self->priv->ring_proxy, TELEPATHY_ACCOUNT_PROP_CHANGED, dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE), G_TYPE_INVALID);
 	dbus_g_proxy_connect_signal (self->priv->ring_proxy, TELEPATHY_ACCOUNT_PROP_CHANGED, G_CALLBACK (callerid_widget_on_property_changed), self, NULL);
 
-	self->priv->sys_dbus_conn = hd_home_plugin_item_get_dbus_g_connection (&self->parent, DBUS_BUS_SYSTEM, NULL);
+	self->priv->sys_dbus_conn = hd_home_plugin_item_get_dbus_g_connection (HD_HOME_PLUGIN_ITEM (self), DBUS_BUS_SYSTEM, NULL);
 	self->priv->bluez_telephony_proxy = dbus_g_proxy_new_for_name (self->priv->sys_dbus_conn, TELEPHONY_MAEMO_SERVICE, TELEPHONY_MAEMO_PATH, TELEPHONY_MAEMO_INTERFACE);
 
 	gtk_window_set_default_size (GTK_WINDOW (self), DEFAULT_WIDTH, DEFAULT_HEIGHT);
